@@ -105,19 +105,34 @@ class CounterfactualManager(BaseManager):
         return dice_explainer
 
     def _add_counterfactual_config(self, new_counterfactual_config):
-        if new_counterfactual_config.features_to_vary != 'all' and \
-                not set(new_counterfactual_config.features_to_vary).issubset(
-                    set(self._train.columns)):
+        if self._model is None:
             raise UserConfigValidationException(
-                'Found some feature names in features_to_vary list which'
-                ' do not occur in train data'
-            )
+                'Model is required for counterfactual example generation and '
+                'feature importances')
+
+        to_vary = new_counterfactual_config.features_to_vary
+        if to_vary != 'all':
+            difference_set = set(to_vary) - set(self._train.columns)
+            if len(difference_set) > 0:
+                message = ("Feature names in features_to_vary do "
+                           f"not exist in train data: {list(difference_set)}")
+                raise UserConfigValidationException(message)
+
+        if new_counterfactual_config.permitted_range is not None:
+            permitted_features = \
+                list(new_counterfactual_config.permitted_range)
+            difference_set = set(permitted_features) - set(self._train.columns)
+            if len(difference_set) > 0:
+                message = ("Feature names in permitted_range do "
+                           f"not exist in train data: {list(difference_set)}")
+                raise UserConfigValidationException(message)
 
         if self._task_type == ModelTask.CLASSIFICATION:
             if new_counterfactual_config.desired_class is None:
                 raise UserConfigValidationException(
                     'The desired_class attribute should be either \'{0}\''
-                    ' or the class value for classification scenarios.'.format(
+                    ' for binary classification or the class value for '
+                    'multi-classification scenarios.'.format(
                         CounterfactualConstants.OPPOSITE))
 
             is_multiclass = len(np.unique(
